@@ -211,6 +211,38 @@ func TestFind(t *testing.T) {
 			wantPR:   13,
 			wantRepo: "https://example.org/OWNER/REPO",
 		},
+		{
+			name: "PR URL argument and not in a local git repo",
+			args: args{
+				selector:   "https://example.org/OWNER/REPO/pull/13/files",
+				fields:     []string{"id", "number"},
+				baseRepoFn: nil,
+				branchFn: func() (string, error) {
+					return "", &git.GitError{
+						Stderr:   "fatal: branchFn error",
+						ExitCode: 128,
+					}
+				},
+				branchConfig: stubBranchConfig(git.BranchConfig{}, &git.GitError{
+					Stderr:   "fatal: branchConfig error",
+					ExitCode: 128,
+				}),
+				pushDefault: stubPushDefault("simple", nil),
+				remotePushDefault: stubRemotePushDefault("", &git.GitError{
+					Stderr:   "fatal: remotePushDefault error",
+					ExitCode: 128,
+				}),
+			},
+			httpStub: func(r *httpmock.Registry) {
+				r.Register(
+					httpmock.GraphQL(`query PullRequestByNumber\b`),
+					httpmock.StringResponse(`{"data":{"repository":{
+						"pullRequest":{"number":13}
+					}}}`))
+			},
+			wantPR:   13,
+			wantRepo: "https://example.org/OWNER/REPO",
+		},
 		{
 			name: "when provided branch argument with an open and closed PR for that branch name, it returns the open PR",
 			args: args{
